'use strict';

/**
 * Module dependencies.
 */

var each = require('@ndhoule/each');
var integration = require('@segment/analytics.js-integration');
var querystring = require('component-querystring');
var useHttps = require('use-https');

/**
 * Expose `AppNexus`.
 */

var AppNexus = module.exports = integration('AppNexus')
  .mapping('events')
  .tag('http', '<script src="http://ib.adnxs.com/px?{{ vars }}">')
  .tag('https', '<script src="https://secure.adnxs.com/px?{{ vars }}">');

/**
 * Loaded.
 *
 * @return {Boolean}
 */

AppNexus.prototype.loaded = function() {
  return true;
};

/**
 * Track.
 *
 * @param {Track} track
 */

AppNexus.prototype.track = function(track) {
  var events = this.events(track.event());
  var self = this;
  each(function(event) {
    return self.conversion(track, event);
  }, events);
};

/**
 * Tracks a conversion.
 *
 * @param {Track} track
 * @param {Object} event
 */

AppNexus.prototype.conversion = function(track, event) {
  var params = event.parameters || {};
  var revenue = track.revenue() || track.total();

  var vars = {
    t: 1,
    id: event.pixelId,
    seg: event.segmentId,
    order_id: track.orderId(),
    value: (revenue || 0).toFixed(2)
  };

  each(function(value, key) {
    vars[value] = track.proxy('properties.' + key);
  }, params);

  var name = useHttps() ? 'https' : 'http';

  this.load(name, { vars: querystring.stringify(vars) });
};
